@@ -93,18 +93,13 @@ dice <- function(data, nk, reps = 10, algorithms = NULL, k.method = NULL,
   #  If more than one k, need to prepend "k=" labels
   if (length(Ecomp) > 1) {
     Final <- purrr::map2(Final, k,
-                         ~ magrittr::set_colnames(.x, paste0(colnames(.),
-                                                             " k=", .y)))
+                         ~ magrittr::set_colnames(.x, paste_k(colnames(.), .y)))
   }
 
   # Relabel Final Clustering using reference (or first column if no reference)
-  if (is.null(ref.cl)) {
-    FinalR <- purrr::map(Final, ~ apply(.x, 2, relabel_class, ref.cl = .x[, 1]))
-  } else {
-    FinalR <- purrr::map(Final, ~ apply(.x, 2, relabel_class, ref.cl = ref.cl))
-  }
-  clusters <- FinalR %>%
-    purrr::invoke(cbind, .) %>%
+  clusters <- Final %>%
+    purrr::map(~ apply(., 2, relabel_class, ref.cl = ref.cl %||% .[, 1])) %>%
+    do.call(cbind, .) %>%
     magrittr::set_rownames(rownames(data))
 
   # Return evaluation output including consensus function results
